@@ -158,7 +158,7 @@ static void pc1350_power_up(int param)
 	power=0;
 }
 
-DRIVER_INIT( pc1350 )
+MACHINE_START( pc1350 )
 {
 	int i;
 	UINT8 *gfx=memory_region(REGION_GFX1);
@@ -166,21 +166,33 @@ DRIVER_INIT( pc1350 )
 
 	timer_pulse(1/500.0, 0,sc61860_2ms_tick);
 	timer_set(1,0,pc1350_power_up);
-}
 
-MACHINE_RESET( pc1350 )
-{
-	if (PC1350_RAM20K)
+	memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x6000, 0x6fff, 0, 0, MRA8_BANK1);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x6fff, 0, 0, MWA8_BANK1);
+	memory_set_bankptr(1, &mess_ram[0x0000]);
+
+	if (mess_ram_size >= 0x3000)
 	{
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x5fff, 0, 0, MWA8_RAM);
-	}
-	else if (PC1350_RAM12K)
-	{
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_RAM);
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MRA8_BANK2);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_BANK2);
+		memory_set_bankptr(2, &mess_ram[0x1000]);
 	}
 	else
 	{
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x5fff, 0, 0, MWA8_NOP);
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_NOP);
 	}
+
+	if (mess_ram_size >= 0x5000)
+	{
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MRA8_BANK3);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_BANK3);
+		memory_set_bankptr(3, &mess_ram[0x3000]);
+	}
+	else
+	{
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
+	}
+	return 0;
 }
