@@ -78,90 +78,50 @@
 #define LOG(N,M,A)
 #endif
 
-ADDRESS_MAP_START( readmem_mz700 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x00fff) AM_READ( MRA8_BANK1 )
-	AM_RANGE( 0x01000, 0x0cfff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x0d000, 0x0d7ff) AM_READ( MRA8_BANK6 )
-	AM_RANGE( 0x0d800, 0x0dfff) AM_READ( MRA8_BANK7 )
-	AM_RANGE( 0x0e000, 0x0ffff) AM_READ( MRA8_BANK8 )
+ADDRESS_MAP_START( mz700_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0x00fff) AM_RAMBANK(1)
+	AM_RANGE( 0x01000, 0x0cfff) AM_RAM
+	AM_RANGE( 0x0d000, 0x0d7ff) AM_RAMBANK(6)
+	AM_RANGE( 0x0d800, 0x0dfff) AM_RAMBANK(7)
+	AM_RANGE( 0x0e000, 0x0ffff) AM_RAMBANK(8)
 #if 0 /*mame37b9 traps */
-	AM_RANGE( 0x10000, 0x10fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x12000, 0x127ff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x12800, 0x12fff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x16000, 0x16fff) AM_READ( MRA8_RAM )
+	AM_RANGE( 0x10000, 0x10fff) AM_ROM
+	AM_RANGE( 0x12000, 0x127ff) AM_READWRITE(MRA8_RAM, videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size )
+	AM_RANGE( 0x12800, 0x12fff) AM_READWRITE(MRA8_RAM, colorram_w) AM_BASE( &colorram )
+	AM_RANGE( 0x16000, 0x16fff) AM_READWRITE(MRA8_RAM, pcgram_w)
 #endif
 ADDRESS_MAP_END
 
-ADDRESS_MAP_START( writemem_mz700 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x00fff) AM_WRITE( MWA8_BANK1 )
-	AM_RANGE( 0x01000, 0x0cfff) AM_WRITE( MWA8_RAM )
-	AM_RANGE( 0x0d000, 0x0d7ff) AM_WRITE( MWA8_BANK6 )
-	AM_RANGE( 0x0d800, 0x0dfff) AM_WRITE( MWA8_BANK7 )
-	AM_RANGE( 0x0e000, 0x0ffff) AM_WRITE( MWA8_BANK8 )
+ADDRESS_MAP_START(mz700_io, ADDRESS_SPACE_IO, 8)
+	AM_RANGE(0xe0, 0xe6) AM_WRITE( mz700_bank_w )
+ADDRESS_MAP_END
+
+ADDRESS_MAP_START(mz800_mem, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x00000, 0x00fff) AM_RAMBANK(1)
+	AM_RANGE( 0x01000, 0x01fff) AM_RAMBANK(2)
+	AM_RANGE( 0x02000, 0x07fff) AM_RAM
+	AM_RANGE( 0x08000, 0x09fff) AM_RAMBANK(3)
+	AM_RANGE( 0x0a000, 0x0bfff) AM_RAMBANK(4)
+	AM_RANGE( 0x0c000, 0x0cfff) AM_RAMBANK(5)
+	AM_RANGE( 0x0d000, 0x0d7ff) AM_RAMBANK(6)
+	AM_RANGE( 0x0d800, 0x0dfff) AM_RAMBANK(7)
+	AM_RANGE( 0x0e000, 0x0ffff) AM_RAMBANK(8)
 #if 0
-	AM_RANGE( 0x12000, 0x127ff) AM_WRITE( videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
-	AM_RANGE( 0x12800, 0x12fff) AM_WRITE( colorram_w) AM_BASE( &colorram )
-	AM_RANGE( 0x16000, 0x16fff) AM_WRITE( pcgram_w )
-#endif
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( readport_mz700 , ADDRESS_SPACE_IO, 8)
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( writeport_mz700 , ADDRESS_SPACE_IO, 8)
-	AM_RANGE( 0xe0, 0xe6) AM_WRITE( mz700_bank_w )
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( readmem_mz800 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x00fff) AM_READ( MRA8_BANK1 )
-	AM_RANGE( 0x01000, 0x01fff) AM_READ( MRA8_BANK2 )
-	AM_RANGE( 0x02000, 0x07fff) AM_READ( MRA8_RAM )
-	AM_RANGE( 0x08000, 0x09fff) AM_READ( MRA8_BANK3 )
-	AM_RANGE( 0x0a000, 0x0bfff) AM_READ( MRA8_BANK4 )
-	AM_RANGE( 0x0c000, 0x0cfff) AM_READ( MRA8_BANK5 )
-	AM_RANGE( 0x0d000, 0x0d7ff) AM_READ( MRA8_BANK6 )
-	AM_RANGE( 0x0d800, 0x0dfff) AM_READ( MRA8_BANK7 )
-	AM_RANGE( 0x0e000, 0x0ffff) AM_READ( MRA8_BANK8 )
-#if 0
-	AM_RANGE( 0x10000, 0x10fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x11000, 0x11fff) AM_READ( MRA8_ROM )
-	AM_RANGE( 0x12000, 0x15fff) AM_READ( MRA8_RAM )
-#endif
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( writemem_mz800 , ADDRESS_SPACE_PROGRAM, 8)
-	AM_RANGE( 0x00000, 0x00fff) AM_WRITE( MWA8_BANK1 )
-	AM_RANGE( 0x01000, 0x01fff) AM_WRITE( MWA8_BANK2 )
-	AM_RANGE( 0x02000, 0x07fff) AM_WRITE( MWA8_RAM )
-	AM_RANGE( 0x08000, 0x09fff) AM_WRITE( MWA8_BANK3 )
-	AM_RANGE( 0x0a000, 0x0bfff) AM_WRITE( MWA8_BANK4 )
-	AM_RANGE( 0x0c000, 0x0cfff) AM_WRITE( MWA8_BANK5 )
-	AM_RANGE( 0x0d000, 0x0d7ff) AM_WRITE( MWA8_BANK6 )
-	AM_RANGE( 0x0d800, 0x0dfff) AM_WRITE( MWA8_BANK7 )
-	AM_RANGE( 0x0e000, 0x0ffff) AM_WRITE( MWA8_BANK8 )
-#if 0
-	AM_RANGE( 0x10000, 0x10fff) AM_WRITE( MWA8_ROM )
-	AM_RANGE( 0x11000, 0x11fff) AM_WRITE( MWA8_ROM )
-    AM_RANGE( 0x12000, 0x16fff) AM_WRITE( videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
+	AM_RANGE( 0x10000, 0x10fff) AM_ROM
+	AM_RANGE( 0x11000, 0x11fff) AM_ROM
+	AM_RANGE( 0x12000, 0x16fff) AM_READWRITE(MRA8_RAM, videoram_w) AM_BASE( &videoram) AM_SIZE( &videoram_size )
 	AM_RANGE( 0x12800, 0x12fff) AM_WRITE( colorram_w) AM_BASE( &colorram )
 #endif
-ADDRESS_MAP_END
+	ADDRESS_MAP_END
 
-ADDRESS_MAP_START( readport_mz800 , ADDRESS_SPACE_IO, 8)
-	AM_RANGE( 0xce, 0xce) AM_READ( mz800_crtc_r )
-	AM_RANGE( 0xd0, 0xd7) AM_READ( mz800_mmio_r )
-	AM_RANGE( 0xe0, 0xe9) AM_READ( mz800_bank_r )
-	AM_RANGE( 0xea, 0xea) AM_READ( mz800_ramdisk_r )
-ADDRESS_MAP_END
-
-ADDRESS_MAP_START( writeport_mz800 , ADDRESS_SPACE_IO, 8)
+ADDRESS_MAP_START(mz800_io, ADDRESS_SPACE_IO, 8)
 	AM_RANGE( 0xcc, 0xcc) AM_WRITE( mz800_write_format_w )
 	AM_RANGE( 0xcd, 0xcd) AM_WRITE( mz800_read_format_w )
-	AM_RANGE( 0xce, 0xce) AM_WRITE( mz800_display_mode_w )
+	AM_RANGE( 0xce, 0xce) AM_READWRITE( mz800_crtc_r, mz800_display_mode_w )
 	AM_RANGE( 0xcf, 0xcf) AM_WRITE( mz800_scroll_border_w )
-	AM_RANGE( 0xd0, 0xd7) AM_WRITE( mz800_mmio_w )
-	AM_RANGE( 0xe0, 0xe9) AM_WRITE( mz800_bank_w )
-	AM_RANGE( 0xea, 0xea) AM_WRITE( mz800_ramdisk_w )
+	AM_RANGE( 0xd0, 0xd7) AM_READWRITE( mz800_mmio_r, mz800_mmio_w )
+	AM_RANGE( 0xe0, 0xe9) AM_READWRITE( mz800_bank_r, mz800_bank_w )
+	AM_RANGE( 0xea, 0xea) AM_READWRITE( mz800_ramdisk_r, mz800_ramdisk_w )
 	AM_RANGE( 0xeb, 0xeb) AM_WRITE( mz800_ramaddr_w )
 	AM_RANGE( 0xf0, 0xf0) AM_WRITE( mz800_palette_w )
 ADDRESS_MAP_END
@@ -301,15 +261,15 @@ static MACHINE_DRIVER_START(mz700)
 	/* Z80 CPU @ 3.5 MHz */
 	MDRV_CPU_ADD(Z80, 3500000)
 	/*MDRV_CPU_CONFIG(0)*/
-	MDRV_CPU_PROGRAM_MAP(readmem_mz700, writemem_mz700)
-	MDRV_CPU_IO_MAP(readport_mz700, writeport_mz700)
+	MDRV_CPU_PROGRAM_MAP(mz700_mem, 0)
+	MDRV_CPU_IO_MAP(mz700_io, 0)
 	/*MDRV_CPU_PERIODIC_INT(func, rate)*/
 
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(2500)
 	/*MDRV_INTERLEAVE(interleave)*/
 
-	MDRV_MACHINE_INIT( mz700 )
+	MDRV_MACHINE_RESET( mz700 )
 	/*MDRV_NVRAM_HANDLER( NULL )*/
 
 	/* video hardware - include overscan */
@@ -339,13 +299,13 @@ static MACHINE_DRIVER_START(mz800)
 	/* basic machine hardware */
 	/* Z80 CPU @ 3.5 MHz */
 	MDRV_CPU_ADD(Z80, 3500000)
-	MDRV_CPU_PROGRAM_MAP(readmem_mz800, writemem_mz800)
-	MDRV_CPU_IO_MAP(readport_mz800, writeport_mz800)
+	MDRV_CPU_PROGRAM_MAP(mz800_mem, 0)
+	MDRV_CPU_IO_MAP(mz800_io, 0)
 
 	MDRV_FRAMES_PER_SECOND(50)
 	MDRV_VBLANK_DURATION(2500)
 
-	MDRV_MACHINE_INIT( mz700 )
+	MDRV_MACHINE_RESET( mz700 )
 
 	/* video hardware - include overscan */
 	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
