@@ -182,10 +182,6 @@ VIDEO_START( newport )
 	nREX3_DCBMode = 0x00000780;
 	nREX3_Kludge_SkipLine = 0;
 	video_base = auto_malloc( (1280+64) * (1024+64) * 4 );
-	if( video_base == NULL )
-	{
-		return 1;
-	}
 	memset( video_base, 0x00, (1280+64) * (1024+64) * 4 );
 	return 0;
 }
