@@ -14,8 +14,9 @@
 #ifndef __CDROM_H__
 #define __CDROM_H__
 
-#include "driver.h"
+#include "mamecore.h"
 #include "chd.h"
+#include "streams.h"
 
 typedef struct _cdrom_file cdrom_file;
 
