@@ -16,7 +16,7 @@ INLINE void illegal( void )
 {
 	LOG(("HD6309: illegal opcode at %04x\nVectoring to [$fff0]\n",PC));
 
-	CC |= CC_E; 				/* save entire state */
+	CC |= CC_E | CC_IF | CC_II;
 	PUSHWORD(pPC);
 	PUSHWORD(pU);
 	PUSHWORD(pY);
@@ -226,6 +226,9 @@ INLINE void jmp_di( void )
 INLINE void clr_di( void )
 {
 	DIRECT;
+#ifdef MESS
+	RM(EAD);
+#endif
 	WM(EAD,0);
 	CLR_NZVC;
 	SEZ;
@@ -254,7 +257,7 @@ INLINE void sync( void )
 	hd6309.int_state |= HD6309_SYNC;	 /* HJB 990227 */
 	CHECK_IRQ_LINES();
 	/* if HD6309_SYNC has not been cleared by CHECK_IRQ_LINES(),
-	 * stop execution until the interrupt lines change. */
+     * stop execution until the interrupt lines change. */
 	if( hd6309.int_state & HD6309_SYNC )
 		if (hd6309_ICount > 0) hd6309_ICount = 0;
 }
@@ -262,12 +265,13 @@ INLINE void sync( void )
 /* $14 sexw inherent */
 INLINE void sexw( void )
 {
-	UINT32 t;
-	t = SIGNED_16(W);
-	D = t;
+	PAIR q;
+	q.d = SIGNED_16(W);
+	D = q.w.h;
+	W = q.w.l;
 	CLR_NZV;
-	SET_N8(A);
-	if ( D == 0 && W == 0 ) SEZ;
+	SET_N16(D);
+	SET_Z(q.d);
 }
 
 /* $15 ILLEGAL */
@@ -336,7 +340,7 @@ INLINE void sex( void )
 	UINT16 t;
 	t = SIGNED(B);
 	D = t;
-	CLR_NZV;
+	CLR_NZ;
 	SET_NZ16(t);
 }
 
@@ -1036,7 +1040,7 @@ INLINE void tfmpp( void )
 		}
 	}
 	else
-		hd6309_ICount -= 3;   /* Needs three aditional cycles  to get the 6+3n */
+		hd6309_ICount -= 6;   /* Needs six aditional cycles to get the 6+3n */
 }
 
 /* $1139 TFM R0-,R1- */
@@ -1095,7 +1099,7 @@ INLINE void tfmmm( void )
 		}
 	}
 	else
-		hd6309_ICount -= 3;   /* Needs three aditional cycles  to get the 6+3n */
+		hd6309_ICount -= 6;   /* Needs six aditional cycles to get the 6+3n */
 }
 
 /* $113A TFM R0+,R1 */
@@ -1154,7 +1158,7 @@ INLINE void tfmpc( void )
 		}
 	}
 	else
-		hd6309_ICount -= 3;   /* Needs three aditional cycles  to get the 6+3n */
+		hd6309_ICount -= 6;   /* Needs six aditional cycles to get the 6+3n */
 }
 
 /* $113B TFM R0,R1+ */
@@ -1213,7 +1217,7 @@ INLINE void tfmcp( void )
 		}
 	}
 	else
-		hd6309_ICount -= 3;   /* Needs three aditional cycles  to get the 6+3n */
+		hd6309_ICount -= 6;   /* Needs six aditional cycles to get the 6+3n */
 }
 
 /* $30 LEAX indexed --*-- */
@@ -1388,10 +1392,10 @@ INLINE void cwai( void )
 	IMMBYTE(t);
 	CC &= t;
 	/*
-	 * CWAI stacks the entire machine state on the hardware stack,
-	 * then waits for an interrupt; when the interrupt is taken
-	 * later, the state is *not* saved again after CWAI.
-	 */
+     * CWAI stacks the entire machine state on the hardware stack,
+     * then waits for an interrupt; when the interrupt is taken
+     * later, the state is *not* saved again after CWAI.
+     */
 	CC |= CC_E; 		/* HJB 990225: save entire state */
 	PUSHWORD(pPC);
 	PUSHWORD(pU);
@@ -1437,7 +1441,6 @@ INLINE void swi( void )
 	{
 		PUSHBYTE(F);
 		PUSHBYTE(E);
-		hd6309_ICount -= 2;
 	}
 	PUSHBYTE(B);
 	PUSHBYTE(A);
@@ -1449,13 +1452,14 @@ INLINE void swi( void )
 
 /* $1130 BAND */
 
-#define decodePB_tReg(n)	((n)&3)
-#define decodePB_src(n) 	(((n)>>2)&7)
-#define decodePB_dst(n) 	(((n)>>5)&7)
+#define decodePB_tReg(n)	(((n) >> 6) & 0x03)
+#define decodePB_src(n) 	(((n) >> 3) & 0x07)
+#define decodePB_dst(n) 	(((n) >> 0) & 0x07)
 
-static unsigned char *	regTable[4] = { &(CC), &(A), &(B), &(E) };
+static UINT8 dummy_byte;
+static unsigned char *regTable[4] = { &(CC), &(A), &(B), &dummy_byte };
 
-static UINT8	bitTable[] = { 0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80 };
+static const UINT8 bitTable[] = { 0x01, 0x02, 0x04, 0x08, 0x10, 0x20, 0x40, 0x80 };
 
 INLINE void band( void )
 {
@@ -1612,7 +1616,6 @@ INLINE void swi2( void )
 	{
 		PUSHBYTE(F);
 		PUSHBYTE(E);
-		hd6309_ICount -= 2;
 	}
 	PUSHBYTE(B);
 	PUSHBYTE(A);
@@ -1634,7 +1637,6 @@ INLINE void swi3( void )
 	{
 		PUSHBYTE(F);
 		PUSHBYTE(E);
-		hd6309_ICount -= 2;
 	}
 	PUSHBYTE(B);
 	PUSHBYTE(A);
@@ -2310,6 +2312,9 @@ INLINE void jmp_ix( void )
 INLINE void clr_ix( void )
 {
 	fetch_effective_address();
+#ifdef MESS
+	RM(EAD);
+#endif
 	WM(EAD,0);
 	CLR_NZVC; SEZ;
 }
@@ -2467,6 +2472,9 @@ INLINE void jmp_ex( void )
 INLINE void clr_ex( void )
 {
 	EXTENDED;
+#ifdef MESS
+	RM(EAD);
+#endif
 	WM(EAD,0);
 	CLR_NZVC; SEZ;
 }
@@ -2734,12 +2742,13 @@ INLINE void muld_im( void )
 INLINE void divd_im( void )
 {
 	UINT8   t;
-	INT16   v;
+	INT16   v, oldD;
 
 	IMMBYTE( t );
 
 	if( t != 0 )
 	{
+		oldD = D;
 		v = (INT16) D / (INT8) t;
 		A = (INT16) D % (INT8) t;
 		B = v;
@@ -2750,8 +2759,19 @@ INLINE void divd_im( void )
 		if( B & 0x01 )
 			SEC;
 
-		if ( (v > 127) || (v < -128) )
+		if( (INT16)D < 0 )
+			SEN;
+
+		if ( (v > 127) || (v < -128) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 255) || (v < -256) ) /* hard overflow - division is aborted */
+			{
+				SET_NZ16( oldD );
+				D = abs( oldD );
+			}
+		}
 	}
 	else
 	{
@@ -2763,15 +2783,18 @@ INLINE void divd_im( void )
 /* $118e DIVQ immediate */
 INLINE void divq_im( void )
 {
-	PAIR	t,q;
+	PAIR	t,q, oldQ;
 	INT32	v;
 
 	IMMWORD( t );
+
 	q.w.h = D;
 	q.w.l = W;
 
 	if( t.w.l != 0 )
 	{
+		oldQ = q;
+
 		v = (INT32) q.d / (INT16) t.w.l;
 		D = (INT32) q.d % (INT16) t.w.l;
 		W = v;
@@ -2782,8 +2805,22 @@ INLINE void divq_im( void )
 		if( W & 0x0001 )
 			SEC;
 
-		if ( (v > 65534) || (v < -65535) )
+		if ( (v > 32768) || (v < -35767) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 65536 ) || (v < -65535 ) ) /* hard overflow - division is aborted */
+			{
+				if( oldQ.d < 0 )
+					SEN;
+				else if( oldQ.d == 0 )
+					SEZ;
+
+				t.w.l = abs( t.w.l );
+				D = oldQ.w.h;
+				W = oldQ.w.l;
+			}
+		}
 	}
 	else
 		DZError();
@@ -2915,13 +2952,6 @@ INLINE void lda_di( void )
 	SET_NZ8(A);
 }
 
-/* $113d LDMD direct -**0- */
-INLINE void ldmd_di( void )
-{
-	DIRBYTE(MD);
-	UpdateState();
-}
-
 /* $97 STA direct -**0- */
 INLINE void sta_di( void )
 {
@@ -3046,12 +3076,13 @@ INLINE void muld_di( void )
 INLINE void divd_di( void )
 {
 	UINT8	t;
-	INT16   v;
+	INT16   v, oldD;
 
 	DIRBYTE(t);
 
 	if( t != 0 )
 	{
+		oldD = D;
 		v = (INT16) D / (INT8) t;
 		A = (INT16) D % (INT8) t;
 		B = v;
@@ -3062,8 +3093,19 @@ INLINE void divd_di( void )
 		if( B & 0x01 )
 			SEC;
 
-		if ( (v > 127) || (v < -128) )
+		if( (INT16)D < 0 )
+			SEN;
+
+		if ( (v > 127) || (v < -128) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 255) || (v < -256) ) /* hard overflow - division is aborted */
+			{
+				SET_NZ16( oldD );
+				D = abs( oldD );
+			}
+		}
 	}
 	else
 	{
@@ -3075,16 +3117,18 @@ INLINE void divd_di( void )
 /* $119e DIVQ direct -**0- */
 INLINE void divq_di( void )
 {
-	PAIR	t, q;
+	PAIR	t,q, oldQ;
 	INT32	v;
 
+	DIRWORD(t);
+
 	q.w.h = D;
 	q.w.l = W;
 
-	DIRWORD(t);
-
 	if( t.w.l != 0 )
 	{
+		oldQ = q;
+
 		v = (INT32) q.d / (INT16) t.w.l;
 		D = (INT32) q.d % (INT16) t.w.l;
 		W = v;
@@ -3095,13 +3139,26 @@ INLINE void divq_di( void )
 		if( W & 0x0001 )
 			SEC;
 
-		if ( (v > 65534) || (v < -65535) )
+		if ( (v > 32767) || (v < -32768) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 65535 ) || (v < -65536 ) ) /* hard overflow - division is aborted */
+			{
+				if( oldQ.d < 0 )
+					SEN;
+				else if( oldQ.d == 0 )
+					SEZ;
+
+				t.w.l = abs( t.w.l );
+				D = oldQ.w.h;
+				W = oldQ.w.l;
+			}
+		}
 	}
 	else
 		DZError();
 }
-
 /* $10dc LDQ direct -**0- */
 INLINE void ldq_di( void )
 {
@@ -3419,13 +3476,14 @@ INLINE void muld_ix( void )
 INLINE void divd_ix( void )
 {
 	UINT8	t;
-	INT16   v;
+	INT16   v, oldD;
 
 	fetch_effective_address();
 	t=RM(EAD);
 
 	if( t != 0 )
 	{
+		oldD = D;
 		v = (INT16) D / (INT8) t;
 		A = (INT16) D % (INT8) t;
 		B = v;
@@ -3436,8 +3494,19 @@ INLINE void divd_ix( void )
 		if( B & 0x01 )
 			SEC;
 
-		if ( (v > 127) || (v < -128) )
+		if( (INT16)D < 0 )
+			SEN;
+
+		if ( (v > 127) || (v < -128) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 255) || (v < -256) ) /* hard overflow - division is aborted */
+			{
+				SET_NZ16( oldD );
+				D = abs( oldD );
+			}
+		}
 	}
 	else
 	{
@@ -3449,20 +3518,21 @@ INLINE void divd_ix( void )
 /* $11ae DIVQ indexed -**0- */
 INLINE void divq_ix( void )
 {
-	UINT16	t;
+	PAIR	t,q, oldQ;
 	INT32	v;
-	PAIR	q;
+
+	fetch_effective_address();
+	t.w.l=RM16(EAD);
 
 	q.w.h = D;
 	q.w.l = W;
 
-	fetch_effective_address();
-	t=RM16(EAD);
-
-	if( t != 0 )
+	if( t.w.l != 0 )
 	{
-		v = (INT32) q.d / (INT16) t;
-		D = (INT32) q.d % (INT16) t;
+		oldQ = q;
+
+		v = (INT32) q.d / (INT16) t.w.l;
+		D = (INT32) q.d % (INT16) t.w.l;
 		W = v;
 
 		CLR_NZVC;
@@ -3471,8 +3541,22 @@ INLINE void divq_ix( void )
 		if( W & 0x0001 )
 			SEC;
 
-		if ( (v > 65534) || (v < -65535) )
+		if ( (v > 32767) || (v < -32768) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 65535 ) || (v < -65536 ) ) /* hard overflow - division is aborted */
+			{
+				if( oldQ.d < 0 )
+					SEN;
+				else if( oldQ.d == 0 )
+					SEZ;
+
+				t.w.l = abs( t.w.l );
+				D = oldQ.w.h;
+				W = oldQ.w.l;
+			}
+		}
 	}
 	else
 		DZError();
@@ -3782,12 +3866,13 @@ INLINE void muld_ex( void )
 INLINE void divd_ex( void )
 {
 	UINT8	t;
-	INT16   v;
+	INT16   v, oldD;
 
 	EXTBYTE(t);
 
 	if( t != 0 )
 	{
+		oldD = D;
 		v = (INT16) D / (INT8) t;
 		A = (INT16) D % (INT8) t;
 		B = v;
@@ -3798,8 +3883,19 @@ INLINE void divd_ex( void )
 		if( B & 0x01 )
 			SEC;
 
-		if ( (v > 127) || (v < -128) )
+		if( (INT16)D < 0 )
+			SEN;
+
+		if ( (v > 127) || (v < -128) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 255) || (v < -256) ) /* hard overflow - division is aborted */
+			{
+				SET_NZ16( oldD );
+				D = abs( oldD );
+			}
+		}
 	}
 	else
 	{
@@ -3811,16 +3907,18 @@ INLINE void divd_ex( void )
 /* $11be DIVQ extended -**0- */
 INLINE void divq_ex( void )
 {
-	PAIR	t, q;
+	PAIR	t,q, oldQ;
 	INT32	v;
 
+	EXTWORD(t);
+
 	q.w.h = D;
 	q.w.l = W;
 
-	EXTWORD(t);
-
 	if( t.w.l != 0 )
 	{
+		oldQ = q;
+
 		v = (INT32) q.d / (INT16) t.w.l;
 		D = (INT32) q.d % (INT16) t.w.l;
 		W = v;
@@ -3831,8 +3929,22 @@ INLINE void divq_ex( void )
 		if( W & 0x0001 )
 			SEC;
 
-		if ( (v > 65534) || (v < -65535) )
+		if ( (v > 32767) || (v < -32768) ) /* soft overflow */
+		{
 			SEV;
+
+			if( (v > 65535 ) || (v < -65536 ) ) /* hard overflow - division is aborted */
+			{
+				if( oldQ.d < 0 )
+					SEN;
+				else if( oldQ.d == 0 )
+					SEZ;
+
+				t.w.l = abs( t.w.l );
+				D = oldQ.w.h;
+				W = oldQ.w.l;
+			}
+		}
 	}
 	else
 		DZError();
@@ -4095,8 +4207,7 @@ INLINE void ldb_im( void )
 INLINE void ldmd_im( void )
 {
 	IMMBYTE(MD);
-/*	CLR_NZV;	*/
-/*	SET_NZ8(B); */
+	UpdateState();
 }
 
 /* $1186 LDE immediate -**0- */
@@ -4154,7 +4265,7 @@ INLINE void adcd_im( void )
 	UINT32	r;
 	IMMWORD(t);
 	r = D + t.w.l + (CC & CC_C);
-	CLR_HNZVC;
+	CLR_NZVC;
 	SET_FLAGS16(D,t.w.l,r);
 	D = r;
 }
@@ -4496,11 +4607,13 @@ INLINE void adcb_di( void )
 /* $1099 adcd direct ***** */
 INLINE void adcd_di( void )
 {
-	UINT32 t,r;
-	DIRBYTE(t);
-	r = D + t + (CC & CC_C);
-	CLR_HNZVC;
-	SET_FLAGS16(D,t,r);
+	UINT32	r;
+	PAIR	t;
+
+	DIRWORD(t);
+	r = D + t.w.l + (CC & CC_C);
+	CLR_NZVC;
+	SET_FLAGS16(D,t.w.l,r);
 	D = r;
 }
 
@@ -4887,12 +5000,13 @@ INLINE void adcb_ix( void )
 /* $10a9 ADCD indexed ***** */
 INLINE void adcd_ix( void )
 {
-	UINT32 t,r;
+	UINT32	r;
+	PAIR	t;
 	fetch_effective_address();
-	t = RM(EAD);
-	r = D + t + (CC & CC_C);
-	CLR_HNZVC;
-	SET_FLAGS16(D,t,r);
+	t.d = RM16(EAD);
+	r = D + t.d + (CC & CC_C);
+	CLR_NZVC;
+	SET_FLAGS16(D,t.d,r);
 	D = r;
 }
 
@@ -5266,11 +5380,12 @@ INLINE void adcb_ex( void )
 /* $10b9 ADCD extended ***** */
 INLINE void adcd_ex( void )
 {
-	UINT32 t,r;
-	EXTBYTE(t);
-	r = D + t + (CC & CC_C);
-	CLR_HNZVC;
-	SET_FLAGS16(D,t,r);
+	UINT32	r;
+	PAIR	t;
+	EXTWORD(t);
+	r = D + t.w.l + (CC & CC_C);
+	CLR_NZVC;
+	SET_FLAGS16(D,t.w.l,r);
 	D = r;
 }
 
