@@ -7,9 +7,8 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "vidhrdw/generic.h"
 
-int nmi_enable;
+int yiear_nmi_enable;
 
 static tilemap *bg_tilemap;
 
@@ -83,7 +82,7 @@ WRITE8_HANDLER( yiear_control_w )
 
 	/* bit 1 is NMI enable */
 
-	nmi_enable = data & 0x02;
+	yiear_nmi_enable = data & 0x02;
 
 	/* bit 2 is IRQ enable */
 
